@@ -639,8 +639,7 @@ my ($d, $alias) = @_;
 
 # Remove the alias's .conf file
 &$virtual_server::first_print(&text('feat_deletealias', $d->{'dom'}));
-&unlink_logged(&get_config_file($alias->{'dom'}));
-&unlink_logged(&get_config_file("www.".$alias->{'dom'}));
+&delete_config($alias->{'dom'});
 
 # Remove alias from HostAliases
 &lock_file(&get_config_file($d->{'dom'}));
@@ -810,6 +809,11 @@ sub get_htmldir
 return &virtual_server::public_html_dir($_[0]);
 }
 
+sub template_section
+{
+return ( "web", $text{'tmpl_section'} );
+}
+
 # template_input(&template)
 # Returns HTML for editing per-template options for this plugin
 sub template_input
